==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QAccessibleTextCursorEvent_shell.cpp <==
#include "QAccessibleTextCursorEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleTextCursorEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleTextCursorEvent")
    QAccessibleTextCursorEvent *_ptr = reinterpret_cast<QAccessibleTextCursorEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleTextCursorEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleTextCursorEvent_shell) ); }

jmethodID QAccessibleTextCursorEvent_shell::__shell_javaMethod(int pos) const { return QAccessibleTextCursorEvent_shell::__shell()->javaMethod(typeid(QAccessibleTextCursorEvent), pos); }

// emitting (writeShellConstructor)
QAccessibleTextCursorEvent_shell::QAccessibleTextCursorEvent_shell(QAccessibleInterface* iface0, int cursorPos1)
    : QAccessibleTextCursorEvent(iface0, cursorPos1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleTextCursorEvent::QAccessibleTextCursorEvent_shell(QAccessibleInterface* iface0, int cursorPos1)", QAccessibleTextCursorEvent_shell::__shell())
    QAccessibleTextCursorEvent_shell::__shell()->constructed(typeid(QAccessibleTextCursorEvent));
}

QAccessibleTextCursorEvent_shell::QAccessibleTextCursorEvent_shell(QObject* obj0, int cursorPos1)
    : QAccessibleTextCursorEvent(obj0, cursorPos1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleTextCursorEvent::QAccessibleTextCursorEvent_shell(QObject* obj0, int cursorPos1)", QAccessibleTextCursorEvent_shell::__shell())
    QAccessibleTextCursorEvent_shell::__shell()->constructed(typeid(QAccessibleTextCursorEvent));
}

// emitting (writeShellDestructor)
QAccessibleTextCursorEvent_shell::~QAccessibleTextCursorEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleTextCursorEvent::~QAccessibleTextCursorEvent()", QAccessibleTextCursorEvent_shell::__shell())
    QAccessibleTextCursorEvent_shell::__shell()->destructed(typeid(QAccessibleTextCursorEvent));
}

void QAccessibleTextCursorEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleTextCursorEvent_shell*>(ptr)->QAccessibleTextCursorEvent_shell::__shell()->tryDeleteShell(typeid(QAccessibleTextCursorEvent));
}

// emitting Virtual overrides (virtualFunctions)
QAccessibleInterface* QAccessibleTextCursorEvent_shell::accessibleInterface() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleTextCursorEvent::", QAccessibleTextCursorEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAccessibleInterface*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleTextCursorEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAccessibleInterface* >(__jni_env, __java_return_value);
                } else {
                    QAccessibleTextCursorEvent_shell::__shell()->warnForMethod("QAccessibleTextCursorEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleTextCursorEvent::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAccessibleEvent::accessibleInterface();
        }
    }else{
        return QAccessibleEvent::accessibleInterface();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QAccessibleTextCursorEvent(QAccessibleInterface*,int)
void __qt_construct_QAccessibleTextCursorEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleTextCursorEvent(QAccessibleInterface*,int)")
    jobject iface0 = __java_arguments[0].l;
    QAccessibleInterface* __qt_iface0 = qtjambi_cast<QAccessibleInterface* >(__jni_env, iface0);
    jint cursorPos1 = __java_arguments[1].i;
    Q_UNUSED(cursorPos1)
    QAccessibleTextCursorEvent *__qt_this = new(__qtjambi_ptr) QAccessibleTextCursorEvent_shell(__qt_iface0, static_cast<int>(cursorPos1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QAccessibleTextCursorEvent(QObject*,int)
void __qt_construct_QAccessibleTextCursorEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleTextCursorEvent(QObject*,int)")
    jobject obj0 = __java_arguments[0].l;
    QObject* __qt_obj0 = qtjambi_cast<QObject* >(__jni_env, obj0);
    jint cursorPos1 = __java_arguments[1].i;
    Q_UNUSED(cursorPos1)
    QAccessibleTextCursorEvent *__qt_this = new(__qtjambi_ptr) QAccessibleTextCursorEvent_shell(__qt_obj0, static_cast<int>(cursorPos1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QAccessibleTextCursorEvent_shell
void __qt_destruct_QAccessibleTextCursorEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleTextCursorEvent")
    reinterpret_cast<QAccessibleTextCursorEvent_shell*>(ptr)->~QAccessibleTextCursorEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QAccessibleInterface*,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextCursorEvent_initialize_1native__Lio_qt_gui_QAccessibleTextCursorEvent_2Lio_qt_gui_QAccessibleInterface_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject iface0,
 jint cursorPos1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QAccessibleInterface*,int)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = iface0;
        arguments[1].i = cursorPos1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleTextCursorEvent_0, sizeof(QAccessibleTextCursorEvent_shell), typeid(QAccessibleTextCursorEvent), true, &deleter_QAccessibleTextCursorEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QObject*,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextCursorEvent_initialize_1native__Lio_qt_gui_QAccessibleTextCursorEvent_2Lio_qt_core_QObject_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject obj0,
 jint cursorPos1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QObject*,int)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = obj0;
        arguments[1].i = cursorPos1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleTextCursorEvent_1, sizeof(QAccessibleTextCursorEvent_shell), typeid(QAccessibleTextCursorEvent), true, &deleter_QAccessibleTextCursorEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleTextCursorEvent::cursorPosition()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextCursorEvent_cursorPosition_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleTextCursorEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextCursorEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextCursorEvent::cursorPosition()const", __qt_this)
        __java_return_value = __qt_this->cursorPosition();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleTextCursorEvent::setCursorPosition(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextCursorEvent_setCursorPosition_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint position0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleTextCursorEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextCursorEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextCursorEvent::setCursorPosition(int)", __qt_this)
        __qt_this->setCursorPosition(static_cast<int>(position0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleTextCursorEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleTextCursorEvent>("QAccessibleTextCursorEvent", "io/qt/gui/QAccessibleTextCursorEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibleInterface", "()Lio/qt/gui/QAccessibleInterface;")});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessibleTextCursorEvent, {
        ConstructorInfo(&__qt_construct_QAccessibleTextCursorEvent_0, "Lio/qt/gui/QAccessibleInterface;I")
       ,ConstructorInfo(&__qt_construct_QAccessibleTextCursorEvent_1, "Lio/qt/core/QObject;I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleTextCursorEvent);
    registerSizeOfShell(typeId, sizeof(QAccessibleTextCursorEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QAccessibleEvent, QAccessibleTextCursorEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QAccessibleTextCursorEvent_shell.cpp <==
#include "QAccessibleTextCursorEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleTextCursorEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleTextCursorEvent")
    QAccessibleTextCursorEvent *_ptr = reinterpret_cast<QAccessibleTextCursorEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleTextCursorEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleTextCursorEvent_shell) ); }

jmethodID QAccessibleTextCursorEvent_shell::__shell_javaMethod(int pos) const { return QAccessibleTextCursorEvent_shell::__shell()->javaMethod(typeid(QAccessibleTextCursorEvent), pos); }

// emitting (writeShellConstructor)
QAccessibleTextCursorEvent_shell::QAccessibleTextCursorEvent_shell(QAccessibleInterface* iface0, int cursorPos1)
    : QAccessibleTextCursorEvent(iface0, cursorPos1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleTextCursorEvent::QAccessibleTextCursorEvent_shell(QAccessibleInterface* iface0, int cursorPos1)", QAccessibleTextCursorEvent_shell::__shell())
    QAccessibleTextCursorEvent_shell::__shell()->constructed(typeid(QAccessibleTextCursorEvent));
}

QAccessibleTextCursorEvent_shell::QAccessibleTextCursorEvent_shell(QObject* obj0, int cursorPos1)
    : QAccessibleTextCursorEvent(obj0, cursorPos1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleTextCursorEvent::QAccessibleTextCursorEvent_shell(QObject* obj0, int cursorPos1)", QAccessibleTextCursorEvent_shell::__shell())
    QAccessibleTextCursorEvent_shell::__shell()->constructed(typeid(QAccessibleTextCursorEvent));
}

// emitting (writeShellDestructor)
QAccessibleTextCursorEvent_shell::~QAccessibleTextCursorEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleTextCursorEvent::~QAccessibleTextCursorEvent()", QAccessibleTextCursorEvent_shell::__shell())
    QAccessibleTextCursorEvent_shell::__shell()->destructed(typeid(QAccessibleTextCursorEvent));
}

void QAccessibleTextCursorEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleTextCursorEvent_shell*>(ptr)->QAccessibleTextCursorEvent_shell::__shell()->tryDeleteShell(typeid(QAccessibleTextCursorEvent));
}

// emitting Virtual overrides (virtualFunctions)
QAccessibleInterface* QAccessibleTextCursorEvent_shell::accessibleInterface() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleTextCursorEvent::", QAccessibleTextCursorEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAccessibleInterface*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleTextCursorEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAccessibleInterface* >(__jni_env, __java_return_value);
                } else {
                    QAccessibleTextCursorEvent_shell::__shell()->warnForMethod("QAccessibleTextCursorEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleTextCursorEvent::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAccessibleEvent::accessibleInterface();
        }
    }else{
        return QAccessibleEvent::accessibleInterface();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QAccessibleTextCursorEvent(QAccessibleInterface*,int)
void __qt_construct_QAccessibleTextCursorEvent_QAccessibleInterface_ptr_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleTextCursorEvent(QAccessibleInterface*,int)")
    jobject iface0 = __java_arguments[0].l;
    QAccessibleInterface* __qt_iface0 = qtjambi_cast<QAccessibleInterface* >(__jni_env, iface0);
    jint cursorPos1 = __java_arguments[1].i;
    Q_UNUSED(cursorPos1)
    QAccessibleTextCursorEvent *__qt_this = new(__qtjambi_ptr) QAccessibleTextCursorEvent_shell(__qt_iface0, static_cast<int>(cursorPos1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QAccessibleInterface*,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextCursorEvent_initialize_1native__Lio_qt_gui_QAccessibleTextCursorEvent_2Lio_qt_gui_QAccessibleInterface_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject iface0,
 jint cursorPos1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QAccessibleInterface*,int)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = iface0;
        arguments[1].i = cursorPos1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleTextCursorEvent_QAccessibleInterface_ptr_int, sizeof(QAccessibleTextCursorEvent_shell), typeid(QAccessibleTextCursorEvent), true, &deleter_QAccessibleTextCursorEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QAccessibleTextCursorEvent(QObject*,int)
void __qt_construct_QAccessibleTextCursorEvent_QObject_ptr_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleTextCursorEvent(QObject*,int)")
    jobject obj0 = __java_arguments[0].l;
    QObject* __qt_obj0 = qtjambi_cast<QObject* >(__jni_env, obj0);
    jint cursorPos1 = __java_arguments[1].i;
    Q_UNUSED(cursorPos1)
    QAccessibleTextCursorEvent *__qt_this = new(__qtjambi_ptr) QAccessibleTextCursorEvent_shell(__qt_obj0, static_cast<int>(cursorPos1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QObject*,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextCursorEvent_initialize_1native__Lio_qt_gui_QAccessibleTextCursorEvent_2Lio_qt_core_QObject_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject obj0,
 jint cursorPos1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QObject*,int)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = obj0;
        arguments[1].i = cursorPos1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleTextCursorEvent_QObject_ptr_int, sizeof(QAccessibleTextCursorEvent_shell), typeid(QAccessibleTextCursorEvent), true, &deleter_QAccessibleTextCursorEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAccessibleTextCursorEvent_shell
void __qt_destruct_QAccessibleTextCursorEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleTextCursorEvent")
    reinterpret_cast<QAccessibleTextCursorEvent_shell*>(ptr)->~QAccessibleTextCursorEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleTextCursorEvent::cursorPosition()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextCursorEvent_cursorPosition_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleTextCursorEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextCursorEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextCursorEvent::cursorPosition()const", __qt_this)
        __java_return_value = __qt_this->cursorPosition();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleTextCursorEvent::setCursorPosition(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleTextCursorEvent_setCursorPosition_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint position0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleTextCursorEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleTextCursorEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleTextCursorEvent::setCursorPosition(int)", __qt_this)
        __qt_this->setCursorPosition(static_cast<int>(position0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleTextCursorEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleTextCursorEvent>("QAccessibleTextCursorEvent", "io/qt/gui/QAccessibleTextCursorEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibleInterface", "()Lio/qt/gui/QAccessibleInterface;")});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessibleTextCursorEvent, {
        ConstructorInfo(&__qt_construct_QAccessibleTextCursorEvent_QAccessibleInterface_ptr_int, "Lio/qt/gui/QAccessibleInterface;I")
       ,ConstructorInfo(&__qt_construct_QAccessibleTextCursorEvent_QObject_ptr_int, "Lio/qt/core/QObject;I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleTextCursorEvent);
    registerSizeOfShell(typeId, sizeof(QAccessibleTextCursorEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QAccessibleEvent, QAccessibleTextCursorEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
